import { User, UserManager, type UserManagerSettings } from "oidc-client-ts";
/**
 * @public
 */
export interface AuthProviderProps extends UserManagerSettings {
    /**
     * On sign in callback hook. Can be a async function.
     * Here you can remove the code and state parameters from the url when you are redirected from the authorize page.
     *
     * ```jsx
     * const onSigninCallback = (_user: User | void): void => {
     *     window.history.replaceState(
     *         {},
     *         document.title,
     *         window.location.pathname
     *     )
     * }
     * ```
     */
    onSigninCallback?: (user: User | void) => Promise<void> | void;
    /**
     * By default, if the page url has code/state params, this provider will call automatically the userManager.signinCallback.
     * In some cases the code might be for something else (another OAuth SDK perhaps). In these
     * instances you can instruct the client to ignore them.
     *
     * ```jsx
     * <AuthProvider
     *   skipSigninCallback={window.location.pathname === '/stripe-oauth-callback'}
     * >
     * ```
     */
    skipSigninCallback?: boolean;
    /**
     * On remove user hook. Can be a async function.
     * Here you can change the url after the user is removed.
     *
     * ```jsx
     * const onRemoveUser = (): void => {
     *     // go to home after logout
     *     window.location.pathname = ""
     * }
     * ```
     */
    onRemoveUser?: () => Promise<void> | void;
    /**
     * Allow passing a custom UserManager implementation
     */
    implementation?: typeof UserManager | null;
}
export declare const useOidc: (options: AuthProviderProps) => {
    state: {
        readonly user: import("vue").ComputedRef<{
            id_token?: string | undefined;
            session_state: string | null;
            access_token: string;
            refresh_token?: string | undefined;
            token_type: string;
            scope?: string | undefined;
            profile: {
                [x: string]: unknown;
                [x: number]: unknown;
                auth_time?: number | undefined;
                nonce?: string | undefined;
                acr?: string | undefined;
                amr?: unknown;
                azp?: string | undefined;
                sid?: string | undefined;
                sub: string;
                name?: string | undefined;
                profile?: string | undefined;
                given_name?: string | undefined;
                family_name?: string | undefined;
                middle_name?: string | undefined;
                nickname?: string | undefined;
                preferred_username?: string | undefined;
                picture?: string | undefined;
                website?: string | undefined;
                email?: string | undefined;
                email_verified?: boolean | undefined;
                gender?: string | undefined;
                birthdate?: string | undefined;
                zoneinfo?: string | undefined;
                locale?: string | undefined;
                phone_number?: string | undefined;
                phone_number_verified?: boolean | undefined;
                address?: {
                    formatted?: string | undefined;
                    street_address?: string | undefined;
                    locality?: string | undefined;
                    region?: string | undefined;
                    postal_code?: string | undefined;
                    country?: string | undefined;
                } | undefined;
                updated_at?: number | undefined;
                iss: string;
                aud: string | string[];
                exp: number;
                iat: number;
            };
            expires_at?: number | undefined;
            readonly state: unknown;
            expires_in: number | undefined;
            readonly expired: boolean | undefined;
            readonly scopes: string[];
            toStorageString: () => string;
        } | null | undefined>;
        readonly isLoading: import("vue").ComputedRef<boolean>;
        readonly isAuthenticated: import("vue").ComputedRef<boolean>;
        readonly activeNavigator: import("vue").ComputedRef<"signinRedirect" | "signinPopup" | "signinSilent" | "signoutRedirect" | "signoutPopup" | undefined>;
        readonly error: import("vue").ComputedRef<{
            name: string;
            message: string;
            stack?: string | undefined;
            cause?: any | undefined;
        } | undefined>;
    };
    context: {
        removeUser: () => Promise<void>;
        signinRedirect: (args?: import("oidc-client-ts").SigninRedirectArgs | undefined) => Promise<void>;
        signinPopup: (args?: import("oidc-client-ts").SigninPopupArgs | undefined) => Promise<User>;
        signinSilent: (args?: import("oidc-client-ts").SigninSilentArgs | undefined) => Promise<User | null>;
        signoutRedirect: (args?: import("oidc-client-ts").SignoutRedirectArgs | undefined) => Promise<void>;
        signoutPopup: (args?: import("oidc-client-ts").SignoutPopupArgs | undefined) => Promise<void>;
        clearStaleState: () => Promise<void>;
        querySessionStatus: (args?: import("oidc-client-ts").QuerySessionStatusArgs | undefined) => Promise<import("oidc-client-ts").SessionStatus | null>;
        revokeTokens: (types?: ("access_token" | "refresh_token")[] | undefined) => Promise<void>;
        startSilentRenew: () => void;
        stopSilentRenew: () => void;
        settings: import("oidc-client-ts").UserManagerSettingsStore;
        events: import("oidc-client-ts").UserManagerEvents;
    };
};
